==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterRouteConfigurationMatchBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterRouteConfigurationMatchBuilder extends EnvoyFilterRouteConfigurationMatchFluentImpl<EnvoyFilterRouteConfigurationMatchBuilder> implements VisitableBuilder<EnvoyFilterRouteConfigurationMatch,EnvoyFilterRouteConfigurationMatchBuilder>{
  public EnvoyFilterRouteConfigurationMatchBuilder() {
    this(false);
  }
  public EnvoyFilterRouteConfigurationMatchBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterRouteConfigurationMatch(), validationEnabled);
  }
  public EnvoyFilterRouteConfigurationMatchBuilder(EnvoyFilterRouteConfigurationMatchFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterRouteConfigurationMatchBuilder(EnvoyFilterRouteConfigurationMatchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterRouteConfigurationMatch(), validationEnabled);
  }
  public EnvoyFilterRouteConfigurationMatchBuilder(EnvoyFilterRouteConfigurationMatchFluent<?> fluent,EnvoyFilterRouteConfigurationMatch instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterRouteConfigurationMatchBuilder(EnvoyFilterRouteConfigurationMatchFluent<?> fluent,EnvoyFilterRouteConfigurationMatch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withGateway(instance.getGateway());
      fluent.withName(instance.getName());
      fluent.withPortName(instance.getPortName());
      fluent.withPortNumber(instance.getPortNumber());
      fluent.withVhost(instance.getVhost());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterRouteConfigurationMatchBuilder(EnvoyFilterRouteConfigurationMatch instance) {
    this(instance,false);
  }
  public EnvoyFilterRouteConfigurationMatchBuilder(EnvoyFilterRouteConfigurationMatch instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withGateway(instance.getGateway());
      this.withName(instance.getName());
      this.withPortName(instance.getPortName());
      this.withPortNumber(instance.getPortNumber());
      this.withVhost(instance.getVhost());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterRouteConfigurationMatchFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterRouteConfigurationMatch build() {
    EnvoyFilterRouteConfigurationMatch buildable = new EnvoyFilterRouteConfigurationMatch(fluent.getGateway(),fluent.getName(),fluent.getPortName(),fluent.getPortNumber(),fluent.getVhost());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterRouteConfigurationMatchBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterRouteConfigurationMatchBuilder extends EnvoyFilterRouteConfigurationMatchFluent<EnvoyFilterRouteConfigurationMatchBuilder> implements VisitableBuilder<EnvoyFilterRouteConfigurationMatch,EnvoyFilterRouteConfigurationMatchBuilder>{
  public EnvoyFilterRouteConfigurationMatchBuilder() {
    this(false);
  }
  public EnvoyFilterRouteConfigurationMatchBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterRouteConfigurationMatch(), validationEnabled);
  }
  public EnvoyFilterRouteConfigurationMatchBuilder(EnvoyFilterRouteConfigurationMatchFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterRouteConfigurationMatchBuilder(EnvoyFilterRouteConfigurationMatchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterRouteConfigurationMatch(), validationEnabled);
  }
  public EnvoyFilterRouteConfigurationMatchBuilder(EnvoyFilterRouteConfigurationMatchFluent<?> fluent,EnvoyFilterRouteConfigurationMatch instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterRouteConfigurationMatchBuilder(EnvoyFilterRouteConfigurationMatchFluent<?> fluent,EnvoyFilterRouteConfigurationMatch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new EnvoyFilterRouteConfigurationMatch());

    if (instance != null) {
      fluent.withGateway(instance.getGateway());
      fluent.withName(instance.getName());
      fluent.withPortName(instance.getPortName());
      fluent.withPortNumber(instance.getPortNumber());
      fluent.withVhost(instance.getVhost());
      fluent.withGateway(instance.getGateway());
      fluent.withName(instance.getName());
      fluent.withPortName(instance.getPortName());
      fluent.withPortNumber(instance.getPortNumber());
      fluent.withVhost(instance.getVhost());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterRouteConfigurationMatchBuilder(EnvoyFilterRouteConfigurationMatch instance) {
    this(instance,false);
  }
  public EnvoyFilterRouteConfigurationMatchBuilder(EnvoyFilterRouteConfigurationMatch instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new EnvoyFilterRouteConfigurationMatch());

    if (instance != null) {
      this.withGateway(instance.getGateway());
      this.withName(instance.getName());
      this.withPortName(instance.getPortName());
      this.withPortNumber(instance.getPortNumber());
      this.withVhost(instance.getVhost());
      this.withGateway(instance.getGateway());
      this.withName(instance.getName());
      this.withPortName(instance.getPortName());
      this.withPortNumber(instance.getPortNumber());
      this.withVhost(instance.getVhost());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterRouteConfigurationMatchFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterRouteConfigurationMatch build() {
    EnvoyFilterRouteConfigurationMatch buildable = new EnvoyFilterRouteConfigurationMatch(fluent.getGateway(),fluent.getName(),fluent.getPortName(),fluent.getPortNumber(),fluent.buildVhost());
    return buildable;
  }
  
}
